;****************************
;* Demo Program For ET-SDP8 *
;* Assembler : A180Z        *
;* Hardware : CP-JR180 V2.0 *
;****************************
;
;        I/O LCD PORT
         .EQU  PDATA,0C0H
         .EQU  PSING,0C2H
         .EQU  PREAD,0C4H

         .ORG     8000H
;
;******************************
;*   TEST LCD                 *
;*   16 CHARACTERS * 1 LINE   *
;****************++************
;
TESTLCD:  CALL INITLCD
          LD   HL,TAB161
          CALL WRP
          HALT
;
TAB161:  .DB "*  CP-JR180V2  *"
;
WRP:     LD   A,00H
         CALL GOTO
         CALL WRLINE
         LD   A,40H
         CALL GOTO
         CALL WRLINE
         RET
;
;******** WRITE LINE LCD 16*1 *****
WRLINE:  LD   B,8
TEST11:  LD   A,(HL)
         LD   D,A
         CALL WRBYTE
         INC  HL
         DEC  B
         JP   NZ,TEST11
         RET

;
;***********************
;      INITIAL LCD     *
;***********************
;
INITLCD:   LD   A,00111000B    ;function set  38H
                              ;DL=1 8 bit,N=1 1/16 duty,F=0 5x7
          OUT  (PDATA),A
          CALL DELAY1
          CALL DELAY1        ;DELAY > 4.1 ms
          LD  A,00001111B    ;display on/off control
                              ;D=1 off,C=1 cursor on,B=1 blink
          OUT  (PDATA),A
          CALL DELAY1

          LD   A,00000110B    ;entry mode set
                              ;I/D=1 increment,S=0 right
          OUT  (PDATA),A
          CALL DELAY1

CLSLCD:   LD   A,00000001B    ;clear all display
          OUT  (PDATA),A
          CALL READ
          RET
;
;***** WRITE BYTE SUB ****
;
WRBYTE:  LD  A,D
         OUT (PSING),A
         CALL READ
         RET
;
;***** READY SUB *****
;
DELAY1:   PUSH BC
          PUSH AF
          LD   B,00H
DELAY12:  NOP
          NOP
          NOP
          NOP
          DEC  B
          JP   NZ,DELAY12
          POP  AF
          POP  BC
          RET
;
;******** GOTO ADDR LCD *****
;
GOTO:    SET  7,A
         OUT  (PDATA),A
         CALL  READ
         RET
;
;******** READ BUSY BIT ******
READ:    IN   A,(PREAD)
         NOP
         BIT  7,A
         JP   NZ,READ
         RET
;
;******** SYS CALL GOTOLCD ******
;    INPUT  C = GOTO
;
GOTOLCD: LD   A,C
         CALL GOTO
         RET
;
;******** SYS CALL WBYTE ******
;    INPUT  C = ASCII
WBYTELCD: LD    D,C
          CALL  WRBYTE
          RET
;
;******** SYS CALL STGLCD *****
;    INPUT  DB XX-00H
;
LCDSTG:    POP   HL
WRLCDSTG1: LD    C,(HL)
           INC   HL
           XOR   A
           CP    C
           JP    Z,WRSTG2
           CALL  WBYTELCD
           JP    WRLCDSTG1
WRSTG2:    PUSH  HL
           RET
;
;********* SYS CALL CLCD ******
;    INPUT C = HEX
DSPCLCD:   LD    A,C
           CALL  ASCHEX
           PUSH  DE
           LD    C,D
           CALL  WBYTELCD
           POP   DE
           LD    C,E
           CALL  WBYTELCD
           RET
;
;********* SYS CALL DELCD ******
;
DSPDELCD:  LD    C,D
           PUSH  DE
           CALL  DSPCLCD
           POP   DE
           LD    C,E
           CALL  DSPCLCD
           RET
;
;
;***********************
;  BINARY ACC TO ASCII *
;***********************
;input   = A
;output  = DE (ascii)
;reg     = ADE
;
ASCHEX:  PUSH AF
         RRCA
         RRCA
         RRCA
         RRCA
         CALL ASCH1
         LD   D,A
         POP  AF
;
ASCH1:   AND  0FH
         ADD  A,90H
         DAA
         ADC  A,40H
         DAA
         LD   E,A
         RET
;

            .END


