;****************************
;* Demo Program For LTC1298 *
;* 12-Bit Analog to Digital *
;* Assembler : A180Z        *
;* Hardware : CP-JR180 V2.0 *
;****************************

            .ORG     8000H

;/* JR180 V2.0 Hardware
           .EQU     PA_8255,60H
           .EQU     PB_8255,61H
           .EQU     PC_8255, 62H
           .EQU     PCC_8255,63H
;
           .EQU     PORT_ADC,61H    ; PortB
           .EQU     CLK,1           ; PB1
           .EQU     DOUT,2          ; PB2
           .EQU     CS,3            ; PB3
           .EQU     DIN,4           ; ASCII Status Register0 Address
           .EQU     DCD0,2          ; DCD0 Bit Address


AT8:        LD    A,85H             ; STXSTG
            RST   10H
            .DB   "***** TEST A TO D LTC1298 CH1 *****",0AH,0DH,0
            LD      A,80H
            OUT     (PCC_8255),A
            ;
LOOPAT8:    LD      A,0
            CALL    READ_ADC
            PUSH    HL
            LD      A,83H                   ; DSPC System Call
            LD      C,H
            RST     10H
            POP     HL
            LD      A,83H
            LD      C,L
            RST     10H
            LD      A,82H
            LD      C,0DH
            RST     10H
            CALL    DIS_DELY
            JP      LOOPAT8
;
DIS_DELY:   PUSH AF
            LD   HL,0
DDEL1:      DEC  HL
            LD   A,L
            OR   H
            JP   NZ,DDEL1
            POP  AF
            RET
;


;/**********************/;
;/* Read Data From ADC */;
;/* LTC1298(12Bit A/D) */;
;/* Input  : ACC(ChXX) */;
;/* Output : Reg. HL   */;
;/**********************/;
; START,SGL,ODD,MSBF = ADC
;   1    1   0   X   = Ch0
;   1    1   1   X   = Ch1
; MSBF = 1 = MSB First
; MSBF = 0 = LSB First
; A = 1101 XXXX = Ch0(DF)
; A = 1111 XXXX = Ch1(FF)
;
READ_ADC:   LD      A,0
            RES     CLK,A                   ; Makesure Start Clock
            RES     DOUT,A                  ; Start Bit
            SET     CS,A                    ; Makesure CS=High
            OUT     (PORT_ADC),A
            ;
            RES     CS,A                    ; Start Operation
            OUT     (PORT_ADC),A            ; CS=0
            LD      (RLCA_BUF),A            ; SAVE A PORT

            LD      B,4
ADCOMM:     CALL    CK_LOW
            LD      A,(RLCA_BUF)            ; LOAD A
            SET     DOUT,A                  ; Start Bit = 1 1 1 1
            OUT     (PORT_ADC),A
            LD      (RLCA_BUF),A            ; SAVE A PORT
            CALL    CK_HI
            DEC     B
            JP      NZ,ADCOMM

            CALL    CK_LOW
            CALL    CK_HI
            CALL    CK_LOW
            LD      B,4                     ; Counter MSB 8-Bit (D7..D0)
            LD      A,0
            LD      (ADC_SIGN),A
            ;

RD_ADC3:    CALL    CK_HI
            IN0     A,(DIN)                 ;IN DATA CPU PIN DCD0
            IN0     A,(DIN)                 ;IN DATA CPU PIN DCD0

            BIT     DCD0,A
            JP      NZ,RD31
            XOR     A                       ; CY=0
            JP      RD32
            ;
RD31:       SCF                             ; CY=1
RD32:       LD      A,(ADC_SIGN)
            RL      A
            LD      (ADC_SIGN),A
            CALL    CK_LOW
            DEC     B
            JP      NZ,RD_ADC3
            ;
            LD      A,(ADC_SIGN)
            AND     0FH
            LD      H,A                     ; Data HI byte
;
            LD      B,8                     ; Counter MSB 8-Bit (D7..D0)
            LD      A,0
            LD      (ADC_SIGN),A
            ;
RD_ADC2:    CALL    CK_HI
            IN0     A,(DIN)                 ; IN DATA CPU PIN DCD0
            IN0     A,(DIN)                 ;IN DATA CPU PIN DCD0

            BIT     DCD0,A
            JP      NZ,RD21
            XOR     A                       ; CY=0
            JP      RD22
            ;
RD21:       SCF                             ; CY=1
RD22:       LD      A,(ADC_SIGN)
            RL      A
            LD      (ADC_SIGN),A
            CALL    CK_LOW
            DEC     B
            JP      NZ,RD_ADC2
            ;
            LD      A,(ADC_SIGN)
            LD      L,A                     ; Data LOW byte
            ;
            LD      A,(RLCA_BUF)
            SET     CS,A
            OUT     (PORT_ADC),A
            LD      (RLCA_BUF),A

            RET
;
CK_LOW:     LD      A,(RLCA_BUF)
            RES     CLK,A
            OUT     (PORT_ADC),A
            LD      (RLCA_BUF),A            ; SAVE A PORT
            RET
;
CK_HI:      LD      A,(RLCA_BUF)
            SET     CLK,A
            OUT     (PORT_ADC),A
            LD      (RLCA_BUF),A            ; SAVE A PORT
            RET
;
;**************
;* RAM Buffer *
;**************
;
            .ORG    8800H
RLCA_BUF:   .RS     1                   ; Buffer Rotate Bit
ADC_SIGN:   .RS     1                   ; LTC1298 Signal (CS,DOUT,CLK)

            .END


            
