;*************************************
; PROGRAM Z80180                     *
; ASM SOFTWARE A180Z                 *
; MONITOR PROGRAM COMMON AREA 0      *
;  (LOGICAL ADDRESS)   0000H-7FFFH   *
;  (PHYSICAL ADDRESS)  0000H-7FFFH   *
; RAM  BANK AREA                     *
;  (LOGICAL ADDRESS)   8000H-EFFFH   *
;  (PHYSICAL ADDRESS)  10000H-16FFFH *
; RAM COMMON AREA 1                  *
;  (LOGICAL ADDRESS)   F000H-FFFFH   *
;  (PHYSICAL ADDRESS)  17000H-1FFFFH *
;*************************************
;
;******* ASCI *******
;
        .EQU   FR1,0DBH
        .EQU   FR2,0B0H
        .EQU   CNTLA0,0
        .EQU   CNTLA1,1
        .EQU   CNTLB0,2
        .EQU   CNTLB1,3
        .EQU   STAT0,4
        .EQU   STAT1,5
        .EQU   TDR0,6
        .EQU   TDR1,7
        .EQU   RDR0,8
        .EQU   RDR1,9
;
;*** CSI/O ***
;
        .EQU   CNTR,0AH
        .EQU   TRDR,0BH
;
;*** TIMER ***
;
        .EQU   TMDR0L,0CH
        .EQU   TMDR0H,0DH
        .EQU   RLDR0L,0EH
        .EQU   RLDR0H,0FH
        .EQU   TCR,10H
        .EQU   TMDR1L,14H
        .EQU   TMDR1H,15H
        .EQU   RLDR1L,16H
        .EQU   RLDR1H,17H
;
;*** OTHER ***
;
        .EQU   FRC,18H
;
;*** DMA ***
;
        .EQU   SAR0L,20H
        .EQU   SAR0H,21H
        .EQU   SAR0B,22H
        .EQU   DAR0L,23H
        .EQU   DAR0H,24H
        .EQU   DAR0B,25H
        .EQU   BCR0L,26H
        .EQU   BCR0H,27H
        .EQU   MAR1L,28H
        .EQU   MAR1H,29H
        .EQU   MAR1B,2AH
        .EQU   IAR1L,2BH
        .EQU   IAR1H,2CH
        .EQU   BCR1L,2EH
        .EQU   BCR1H,2FH
        .EQU   DSTAT,30H
        .EQU   DMODE,31H
        .EQU   DCNTL,32H
;
;*** INT ***
;
        .EQU   IL,33H
        .EQU   ITC,34H
;
;*** REFRESH ***
;
        .EQU   RCR,36H
;
;*** MMU ***
;
        .EQU   CBR,38H
        .EQU   BBR,39H
        .EQU   CBAR,3AH
;
;*** I/O ***

        .EQU   OMCR,3EH
        .EQU   ICR,3FH
;
;       END    I/O MAP REG Z80180
;

        .EQU  ORIGIN,0000H
        .ORG  ORIGIN
;
;***********************
;    POWER UP DELAY    *
;***********************
;
INIT:    LD   HL,8000H       ;DELAY
INIT1:   DEC  HL
         LD   A,H
         OR   L
         JR   NZ,INIT1
;
;*** GET MEMORY MAP ***

INIT2:   LD   A,0F8H
         OUT0 (CBAR),A       ;MONITOR 0-7FFF NOT REMOVE
         LD   A,8H
         OUT0 (BBR),A        ;BANK 10000H CAN REMOVE
         OUT0 (CBR),A        ;STACK 10000H NOT REMOVE
         LD   SP,0FFFFH      ;SYSTEM STACK
;
;*** SET INTERRUPT VECTOR ***

         LD   A,0
         LD   I,A            ;VECTOR HIGH
         LD   A,40H          ;VECTOR LOW
         OUT0 (IL),A
         IM   1              ;FOR INT0
         LD   A,8            ;int asci chanel 1
         OUT0 (STAT1),A
         LD   A,64H          ;TX,RX,8BIT,1STOP
         OUT0 (CNTLA1),A
         LD   A,2H           ;9600  AT X'TAL 12.288 MHz
         OUT0 (CNTLB1),A
;
;*** SET INITIAL INTERNAL I/O ***

         LD   A,40H
         OUT0 (OMCR),A       ;SAME Z80
         LD   A,83H
         OUT0 (RCR),A        ;ENABLE REFRESH
         IN0  A,(DCNTL)
         OR   70H
         OUT0 (DCNTL),A      ;MEM 2 WIAT  IO 4
;
;      **************************************
;      *   SOFTWARE FOR CP-jr180V2          *
;      *   EXAMPLE PROGRAM                  *
;      **************************************
;
; I/O CONTROL REGISTER ADDRESS
; I/O LCD PORT
;
         .EQU PA,80H
         .EQU PB,81H
         .EQU PC,82H
         .EQU PCC,83H
;
;      **************************************
;      *   SOFTWARE FOR CP-jr180V2          *
;      *   USER PORT 8255 80H-83H           *
;      **************************************
;
         LD   B,2
LOOP55:  PUSH BC
AT31:    LD   A,80H
         LD   BC,PCC
         OUT  (C),A

         LD   A,01H
;
         LD   D,8
OUTP1:   LD   BC,PA
         CALL OUTP
         CALL SDELAY
         RLCA
         DEC  D
         JR   NZ,OUTP1
;
         LD   A,80H
         LD   D,8
OUTP11:  LD   BC,PA
         CALL OUTP
         CALL SDELAY
         RRCA
         DEC  D
         JR   NZ,OUTP11
         POP  BC
         DEC  B
         JP   NZ,LOOP55
;
;      **************************************
;      *   SOFTWARE FOR CP-jr180V2          *
;      *   IN/OUT RS232-2                   *
;      **************************************
;
;
         LD   C,'T'
         CALL TXBYTE
         LD   C,'E'
         CALL TXBYTE
         LD   C,'S'
         CALL TXBYTE
         LD   C,'T'
         CALL TXBYTE
         LD   C,'>'
         CALL TXBYTE
;

LOOPRS:  CALL  RXBYTE
         LD    C,A
         CALL  TXBYTE
         JP    LOOPRS
;
;-----------------------------
;
OUTP:    PUSH AF
         OUT  (C),A      ;PA
         INC  C
         OUT  (C),A      ;PB
         INC  C
         OUT  (C),A      ;PC
         POP  AF
         RET
;
SDELAY:  PUSH AF
         LD   HL,0
SDEL1:   DEC  HL
         LD   A,L
         OR   H
         JR   NZ,SDEL1
         POP  AF
         RET
;
;
;***********************
;     GET CHARECTER    *
;***********************
;  input   -
;  output  AC
;  reg     C
;
RXBYTE:  DI
;
RXBYTE1: IN0  C,(STAT1)      ;Rxready
         BIT  7,C
         JR   Z,RXBYTE1
         IN0  C,(RDR1)       ;RECEIVE
         LD   A,C
RXBYTE2: EI
         RET
;
;***********************
;   TX ASCII ONE BYTE  *
;***********************
;  input   C
;  output  -
;  reg     AC
;
TXBYTE:  IN0  A,(STAT1)
         BIT  1,A
         JR   Z,TXBYTE
         OUT0 (TDR1),C
         RET
;
;
        .END

