;*****************************
;* Demo Program For Key & SP *
;* Assembler : A180Z         *
;* Hardware  : CP-JR180 V2.0 *
;*****************************
; Key Telephone (4x3) By ETT CO.,LTD
; Keyboard Short Pin1 to 2,Pin4 to 8
; PC0 = Pin 1,2 Keyboard
; PC1 = Pin 3 Keyboard
; PC2 = Pin 5 Keyboard
; PC3 = Pin 6 Keyboard
; PC4 = Pin 7 Keyboard
; PC5 = Pin 8 Keyboard
; PC6 = Pin 9 Keyboard
; PC7 = NC

            .ORG     8000H

;/* JR180 V2.0 Hardware
            .EQU    PA_8255,60H
            .EQU    PB_8255,61H
            .EQU    PC_8255,62H
            .EQU    PCC_8255,63H
            .EQU    PORT_SPK,61H         ; PortB
            .EQU    PORT_KEY,62H         ; PortC
            .EQU    KEY_FLAG,0           ; Keyflag Status
            .EQU    SPEAKER,7            ; PB7

MAIN:       LD      A,88H                   ; PA,PB,PCL=Out,PCH=In
            OUT     (PCC_8255),A
            LD      A,00H
            LD      (SPK_SIGN),A
            ;
LOOP:       CALL    SCAN_KEY
            CP      0FFH
            JP      Z,LOOP
            LD      C,A                     ; Display Keycode
            LD      A,83H                   ; DSPC System Call
            RST     10H
            LD      A,82H
            LD      C,20H
            RST     10H
            JP      LOOP

;********************************
;*  Scan Keyboard Matrix  (4x4) *
;*  PC0..PC3  : Colum (Out)     *
;*  PC4..PC7  : Row (In)        *
;*  Output    : ACC (code 0..F) *
;*            : FFH (Not press) *
;********************************
;
SCAN_KEY:   LD      B,4                 ; Counter for Scan 4x4
            LD      C,11111110B         ; Data for Scan Colum
SCAN1:      LD      A,C
            OUT     (PORT_KEY),A        ; Scan Colum (PC0..PC3)
            IN      A,(PORT_KEY)        ; In Row (PC4..PC7)
            AND     0F0H
            CP      0F0H                ; Check row only (PC4..PC7)
            JP      NZ,KEY_PRES         ; Jump if keypress
            RLC     C                   ; Next Colum
            DJNZ    SCAN1
            LD      A,0FFH              ; Not Keypress
            LD      HL,FLAG_BUF
            RES     KEY_FLAG,(HL)       ; reset flag for key new
            JP      END_SCAN
            ;
KEY_PRES:   CALL    KEY_DLY             ; Debounce key
            IN      A,(PORT_KEY)        ; In Row (PC4..PC7)
            AND     0F0H
            CP      0F0H                ; Check row only (PC4..PC7)
            JP      NZ,KEY_CODE         ; YES keypress
            JP      SCAN_KEY            ; NO keybounce or noise
KEY_CODE:   CALL    KEY_NEW
            JP      C,SCAN1             ; if old key don't care
            PUSH    AF                  ; if new key to get key code
            LD      A,C
            AND     0FH                 ; Check Colum only (PC0..PC3)
            LD      C,A
            POP     AF
            OR      C
            LD      HL,KEY_TAB          ; Row & Colum Code
            LD      B,0
KCODE1:     INC     B
            CP      (HL)
            INC     HL
            JP      NZ,KCODE1
            DEC     B
            LD      A,B                 ; Keycode (0..F)
            CALL    BEEP                ; Beep On Press
END_SCAN:   RET

;********************
;* Check Status Key *
;********************
;
KEY_NEW:    LD      HL,FLAG_BUF
            BIT     KEY_FLAG,(HL)       ; check old key flag
            SCF                         ; Set carry flag if old key
            RET     NZ
            SET     KEY_FLAG,(HL)       ; new key flag
            CCF                         ; Clear carry flag if new key
            RET

;*********************
;* Key Debounce Time *
;*********************
;
KEY_DLY:    PUSH    AF                  ; Delay time for debounce key
            PUSH    HL
            LD      HL,1000
KEY_DLY1:   DEC     HL
            LD      A,L
            OR      H
            JP      NZ,KEY_DLY1
            POP     HL
            POP     AF
            RET

;******************
;* Key Code Table *
;******************
;
KEY_TAB:    .DB     0DEH,0B7H,0D7H      ; 1 2 3
            .DB     0E7H,0BBH,0DBH      ; 4 5 6
            .DB     0EBH,0BDH,0DDH      ; 7 8 9
            .DB     0EDH,0BEH,0EEH      ; * 0 #

;*******************
;* Sound Beep Gen. *
;*******************
;
BEEP:       PUSH    AF
            PUSH    BC
            LD      B,0FFH              ; Freq.
BEEP1:      LD      A,(SPK_SIGN)
            SET     SPEAKER,A
            OUT     (PORT_SPK),A
            LD      (SPK_SIGN),A
            CALL    BEEP_DLY
            LD      A,(SPK_SIGN)
            RES     SPEAKER,A
            OUT     (PORT_SPK),A
            LD      (SPK_SIGN),A
            CALL    BEEP_DLY
            DJNZ    BEEP1
            POP     BC
            POP     AF
            RET

;****************************
;* Gen. frequency for sound *
;****************************
;
BEEP_DLY:   PUSH    BC
            LD      HL,0020H
BEEP_DL1:   DEC     HL
            LD      A,H
            OR      L
            JP      NZ,BEEP_DL1
            POP     BC
            RET

;**************
;* RAM Buffer *
;**************
;
FLAG_BUF:   .DS     1                   ; Keyboard Flag Status
SPK_SIGN:   .DS     1                   ; Speaker Signal

            .END


